@@ -1,10 +1,12 @@
-
 from django.contrib.auth.backends import ModelBackend
-from django.contrib.auth.models import User
 from django.contrib.auth.tokens import default_token_generator
 from django.db.models import Q
 from django.utils.http import base36_to_int
 
+from mezzanine.utils.models import get_user_model
+
+User = get_user_model()
+
 
 class MezzanineBackend(ModelBackend):
     """
